@@ -8,15 +8,15 @@ test_django-plans-payments
 Tests for `django-plans-payments` models module.
 """
 import json
-from decimal import Decimal
 from datetime import datetime
-import pytz
+from decimal import Decimal
 
+import pytz
 from django.test import TestCase
+from freezegun import freeze_time
 from model_bakery import baker
 from payments import PaymentStatus
-from plans.models import Order, Invoice
-from freezegun import freeze_time
+from plans.models import Invoice, Order
 
 from plans_payments import models
 
@@ -128,7 +128,9 @@ class TestPlansPayments(TestCase):
                 ),
             },
         }
-        p = models.Payment(variant="paypal", total=Decimal("10.00"), extra_data=json.dumps(extra_data))
+        p = models.Payment(
+            variant="paypal", total=Decimal("10.00"), extra_data=json.dumps(extra_data)
+        )
         p.save()
         p.save()
         rp = models.Payment.objects.get()
